%define pkgver %(echo %version | sed "s|[a-z]||")
%define javaver %(echo %version | cut -d. -f1-3 | tr -d .)
Name:          opencv49
Version:       4.9.0
Release:       2mamba
Summary:       Collection of algorithms for computer vision
Group:         Development/Libraries
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://opencv.org/
Source:        https://github.com/opencv/opencv.git/%{version}/opencv-%{version}.tar.bz2
Source1:       https://github.com/opencv/opencv_contrib.git/%{version}/opencv_contrib-%{version}.tar.bz2
Patch2:        opencv-2.4.9-buildfix-x86-asm-constraint.patch
Patch3:        opencv-2.4.10-i586-inconsistent-constraint-asm.patch
Patch4:        opencv-4.1.2-cmake-includedir.patch
Patch5:        opencv-4.9.0-contrib-rgbd-glew.patch
License:       BSD
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libQt6Core
BuildRequires: libQt6Gui
BuildRequires: libQt6OpenGL
BuildRequires: libQt6Test
BuildRequires: libQt6Widgets
BuildRequires: libabseil-cpp-devel
BuildRequires: libavcodec-devel
BuildRequires: libavformat-devel
BuildRequires: libavutil-devel
BuildRequires: libdc1394-devel
BuildRequires: libfreetype-devel
BuildRequires: libgcc
BuildRequires: libglib-devel
BuildRequires: libglvnd-devel
BuildRequires: libgst-plugins-base-devel
BuildRequires: libgstreamer-devel
BuildRequires: libharfbuzz-devel
BuildRequires: libhdf5-devel
BuildRequires: libjpeg-turbo
BuildRequires: libopenblas-devel
BuildRequires: libopenexr-devel
BuildRequires: libopenjpeg-devel
BuildRequires: libpng-devel
BuildRequires: libprotobuf-devel
BuildRequires: libpython311-devel
BuildRequires: libstdc++6-devel
BuildRequires: libswscale-devel
BuildRequires: libtbb-devel
BuildRequires: libtesseract-devel
BuildRequires: libtiff-devel
BuildRequires: libvtk-devel
BuildRequires: libwebp-devel
BuildRequires: libxine-devel
BuildRequires: libz-devel
## AUTOBUILDREQ-END
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}

%description
OpenCV (Open Source Computer Vision) is a library of programming functions for real time computer vision.

%package -n lib%{name}
Summary:       Collection of algorithms for computer vision
Group:         System/Libraries

%description -n lib%{name}
OpenCV (Open Source Computer Vision) is a library of programming functions for real time computer vision. 
This package contains the OpenCV static libraries.

%package -n lib%{name}-devel
Summary:       Devel package for %{name}
Group:         Development/Libraries
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}

%description -n lib%{name}-devel
OpenCV (Open Source Computer Vision) is a library of programming functions for real time computer vision. 
This package contains static libraries and header files need for development.

%package -n java-%{name}
Summary:       Java bindings for apps which use OpenCV
Group:         Development/Libraries

%description -n java-%{name}
This package contains Python bindings for the OpenCV library.

%package -n python-cv-py3
Summary:       Python bindings for apps which use OpenCV
Group:         Development/Libraries
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}

%description -n python-cv-py3
This package contains Python bindings for the OpenCV library.

%prep
%setup -q -n opencv-%{version} -a1

%ifarch %{ix86}
%patch 2 -p1
%endif
%patch 4 -p1

cd opencv_contrib-%{version}
%patch 5 -p1
cd ..

# FIXME: removing module requiring Ogre
rm -rf opencv_contrib-%{version}/modules/ovis

%build
#:<< _EOF
export JAVA_HOME=%{_jvmdir}/jdk
export JAVACMD=%{_jvmdir}/jdk/bin/java
#:<< _EOF
#--   Interfaces:
# --     Use IPP:              NO   (Intel Performance Primitive)
# --     Use TBB:              NO   (Threading Building Blocks library)
# --     Build Documentation   0
#
# append flag -D__STDC_CONSTANT_MACROS to fix build with ffmpeg >= 0.6
#PYTHON_PATH=`echo %python36_sitelib | sed "s|%{_prefix}/||"`
%cmake -d build \
 -DCMAKE_BUILD_TYPE=Release \
 -DWITH_OPENCL=ON \
 -DWITH_OPENGL=ON \
 -DOpenGL_GL_PREFERENCE=LEGACY \
 -DCMAKE_CXX_STANDARD=17 \
 -DWITH_TBB=ON \
 -DWITH_VULKAN=ON \
 -DWITH_QT=ON \
 -DWITH_GSTREAMER=1 \
 -DWITH_XINE=1 \
 -DWITH_UNICAP=1 \
 -DWITH_1394=1 \
 -DWITH_FFMPEG=1 \
 -DWITH_QUICKTIME=0 \
 -DBUILD_PROTOBUF=OFF \
 -DPROTOBUF_UPDATE_FILES=ON \
 -DBUILD_SWIG_PYTHON_SUPPORT=1 \
 -DINSTALL_C_EXAMPLES=0 \
 -DCMAKE_CXX_FLAGS:STRING="%{optflags} -D__STDC_CONSTANT_MACROS" \
 -DPYTHON3_EXECUTABLE:PATH=%{__python3} \
 -DPYTHON3_PACKAGES_PATH:PATH=%{python3_sitelib} \
 -DOPENCV_GENERATE_PKGCONFIG=ON \
 -DOPENCV_ENABLE_NONFREE=ON \
 -DOPENCV_EXTRA_MODULES_PATH=${PWD}/../opencv_contrib-%{version}/modules \
 -DENABLE_PRECOMPILED_HEADERS=OFF \
 -DLIB_SUFFIX=

%make_jobs

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%makeinstall -C build

## Fix permissions
#chmod 0755 %{buildroot}%{python_sitearch}/cv2.so
#chmod 0755 %{buildroot}%{python_sitearch}/cv.py

# Remove unpackaged files
rm -fr %{buildroot}%{_datadir}/opencv/doc

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%files
%defattr(-,root,root)
%{_bindir}/opencv_*
%{_bindir}/setup_vars_opencv4.sh
%dir %{_datadir}/opencv4
%{_datadir}/opencv4/*

%files -n lib%{name}
%defattr(-,root,root)
%{_libdir}/libopencv_*.so.*

%files -n lib%{name}-devel
%defattr(-,root,root)
%dir %{_includedir}/opencv4
%dir %{_includedir}/opencv4/opencv2
%{_includedir}/opencv4/opencv2/*
%{_libdir}/libopencv_*.so
%dir %{_libdir}/cmake/opencv4
%{_libdir}/cmake/opencv4/OpenCV*.cmake
%{_libdir}/pkgconfig/opencv4.pc
%dir %{_datadir}/licenses/opencv4
%{_datadir}/licenses/opencv4/*

%files -n java-%{name}
%defattr(-,root,root)
%{_datadir}/java/opencv4/libopencv_java*.so
%{_datadir}/java/opencv4/opencv-*.jar

%files -n python-cv-py3
%defattr(-,root,root)
%dir %{python3_sitelib}/cv2
%{python3_sitelib}/cv2/*

%changelog
* Sun Jan 05 2025 Silvan Calarco <silvan.calarco@mambasoft.it> 4.9.0-2mamba
- legacy package

* Sun Feb 25 2024 Automatic Build System <autodist@openmamba.org> 4.9.0-1mamba
- automatic version update by autodist

* Thu Oct 19 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 4.8.1-2mamba
- obsolete opencv41

* Thu Sep 28 2023 Automatic Build System <autodist@mambasoft.it> 4.8.1-1mamba
- automatic version update by autodist

* Thu Jun 29 2023 Automatic Build System <autodist@mambasoft.it> 4.8.0-1mamba
- automatic version update by autodist

* Sun May 07 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 4.7.0-4mamba
- removed ovis module with dependency on ogre

* Sat May 06 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 4.7.0-3mamba
- rebuilt with ogre 13.6.4

* Sat May 06 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 4.7.0-2mamba
- rebuilt with extra opencv_contrib modules and other cmake options

* Fri Dec 30 2022 Automatic Build System <autodist@mambasoft.it> 4.7.0-1mamba
- automatic version update by autodist

* Tue Jun 07 2022 Automatic Build System <autodist@mambasoft.it> 4.6.0-1mamba
- automatic version update by autodist

* Mon Dec 27 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 4.5.5-1mamba
- update to 4.5.5

* Sat Apr 03 2021 Automatic Build System <autodist@mambasoft.it> 4.5.2-1mamba
- automatic version update by autodist

* Tue Dec 29 2020 Automatic Build System <autodist@mambasoft.it> 4.5.1-1mamba
- automatic version update by autodist

* Sat Dec 12 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 4.5.0-1mamba
- update to 4.5.0

* Sat Dec 12 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.2-5mamba
- rebuilt with python3; updated build requirements

* Sun Dec 08 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.2-4mamba
- rebuilt with -DENABLE_PRECOMPILED_HEADERS=OFF to fix blender build, see https://stackoverflow.com/questions/43558709/opencv-and-tbb-error-x64?rq=1

* Thu Nov 14 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.2-3mamba
- fix cmake file for wrong include dir

* Sat Nov 09 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.2-2mamba
- fix double provide/obsolete for opencv-python

* Fri Oct 11 2019 Automatic Build System <autodist@mambasoft.it> 4.1.2-1mamba
- automatic version update by autodist

* Sun Aug 18 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.1-2mamba
- python-cv-py36: require -py36 packages, not -py3

* Sat Jul 27 2019 Automatic Build System <autodist@mambasoft.it> 4.1.1-1mamba
- automatic version update by autodist

* Thu Apr 25 2019 Automatic Build System <autodist@mambasoft.it> 4.1.0-1mamba
- automatic version update by autodist

* Sat Apr 06 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 4.0.1-1mamba
- update to 4.0.1

* Thu Aug 30 2018 Automatic Build System <autodist@mambasoft.it> 3.4.3-1mamba
- automatic version update by autodist

* Fri Aug 03 2018 Automatic Build System <autodist@mambasoft.it> 3.4.2-1mamba
- automatic version update by autodist

* Mon Jul 30 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4.1-1mamba
- update to 3.4.1

* Thu Jan 21 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 3.1.0-1mamba
- update to 3.1.0

* Wed Dec 23 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.11-3mamba
- rebuilt with gcc 5.3.0

* Tue Sep 22 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.11-2mamba
- libopencv-devel: require java-opencv or provided cmake files fail

* Fri Aug 14 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.11-1mamba
- update to 2.4.11

* Fri May 29 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.10-2mamba
- build kde4 version with gstreamer 0.10 (should fix digikam)

* Sun Dec 28 2014 Automatic Build System <autodist@mambasoft.it> 2.4.10-1mamba
- automatic version update by autodist

* Thu Sep 04 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.9-2mamba
- rebuilt to fix wrong cmake files on i586 which don't like to digikam

* Tue Jul 15 2014 Automatic Build System <autodist@mambasoft.it> 2.4.9-1mamba
- automatic version update by autodist

* Wed Jan 15 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.8-1mamba
- update to 2.4.8

* Wed Nov 13 2013 Automatic Build System <autodist@mambasoft.it> 2.4.7-1mamba
- automatic version update by autodist

* Mon Aug 26 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.6.1-3mamba
- rebuilt after upgrading libatlas-3.8.4-2mamba which fixes python-numpy

* Wed Aug 21 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.6.1-2mamba
- rebuilt with libopenexr-2.0.1-3mamba nad python-numpy 1.8

* Sun Jul 14 2013 Automatic Build System <autodist@mambasoft.it> 2.4.6.1-1mamba
- automatic version update by autodist

* Mon Jul 08 2013 Automatic Build System <autodist@mambasoft.it> 2.4.6-1mamba
- automatic version update by autodist

* Thu Apr 25 2013 Automatic Build System <autodist@mambasoft.it> 2.4.5-1mamba
- update to 2.4.5

* Sat Dec 01 2012 Automatic Build System <autodist@mambasoft.it> 2.4.3-1mamba
- automatic version update by autodist

* Thu Aug 09 2012 Automatic Build System <autodist@mambasoft.it> 2.4.2-1mamba
- automatic version update by autodist

* Fri Dec 09 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.1a-1mamba
- update to 2.3.1a

* Mon Oct 11 2010 Davide Madrisan <davide.madrisan@gmail.com> 2.1.0-1mamba
- update to 2.1.0

* Mon Dec 07 2009 Davide Madrisan <davide.madrisan@gmail.com> 2.0.0-1mamba
- package created by autospec
